@@ -9,26 +9,19 @@ use base 'Class::Accessor';
 
 use Carp 'croak';
 use Convert::Base32 qw( encode_base32 decode_base32 );
-use Crypt::URandom;
+use Crypt::PRNG 'rand';
 use Digest::HMAC_SHA1 'hmac_sha1_hex';
 use URI::Escape 'uri_escape';
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 my @accessors = qw( secret secret32 issuer key_id );
 __PACKAGE__->mk_accessors(@accessors);
 
-sub urand {
-    my ($max) = @_;
-    $max = 1 unless defined $max;
-    $max = abs($max);
-    return unpack( 'Q>', Crypt::URandom::urandom(8) ) / ( 2 ** 64 ) * $max;
-}
-
 sub generate_secret32 {
     my ($self) = @_;
     my @chars = ( 'a' .. 'z', 2 .. 7 );
-    return $self->secret32( join( '', @chars[ map { urand( scalar(@chars) ) } 1 .. 16 ] ) );
+    return $self->secret32( join( '', @chars[ map { rand( scalar(@chars) ) } 1 .. 16 ] ) );
 }
 
 sub clear {
@@ -147,7 +140,7 @@ Auth::GoogleAuth - Google Authenticator TBOT Abstraction
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =for markdown [![test](https://github.com/gryphonshafer/Auth-GoogleAuth/workflows/test/badge.svg)](https://github.com/gryphonshafer/Auth-GoogleAuth/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/Auth-GoogleAuth/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Auth-GoogleAuth)
@@ -340,11 +333,6 @@ all attribute values.
 
     $auth->clear;
 
-=head2 urand
-
-This method is a functional replacement of the core C<rand> but using
-L<Crypt::URandom> for randomness.
-
 =head1 TYPICAL USE-CASE
 
 Typically, you're probably going to want to either randomly generate a secret or
